/*****************************************************
	Definitions for I2C devices on PIC32 Devboard
	- MCP23008 I/O Expander
	- 24FC512 EEPROM Module
******************************************************
	To use these peripherals, the center switch (I2C 
	Enable) must be moved to the "On" position.
*****************************************************/
#pragma once
/*** General ***/
#define I2C_BUS		I2C2	// Bus used on Devboard

/*** IO Expander ***/
/**** MCP23008 ****/
/* To use Interrupt and Reset pins, lower switch must be in "On" position */
#define IOE_ADDR	0x46
#define IOE_WRITE	0x46
#define IOE_READ	0x47
// Internal register addresses
#define IOE_IODIR	0x00	// Direction of IO pins
#define IOE_IPOL	0x01	// Polarity of inputs (can invert)
#define IOE_GPINTEN	0x02	// Enable interrupt on change for pins
#define IOE_DEFVAL	0x03	// Value to compare against for interrupt
#define IOE_INTCON	0x04	// Allows all changes to be captured on pin
#define IOE_IOCON	0x05	// Special device configuration
#define	IOE_GPPU	0x06	// 100-ohm pull-up enable
#define	IOE_INTF	0x07	// Interrupt flags
#define IOE_INTCAP	0x08	// Interrupt capture
#define	IOE_GPIO	0x09	// Input values. Writes here go to OLAT
#define	IOE_OLAT	0x0A	// Output latches


/*** EEPROM ***/
/**** 24FC512 ****/
/* To write to EEPROM, upper switch (Write Enable) must be in "On" position */
#define EE_ADDR		0xA0
#define EE_WRITE	0xA0
#define EE_READ		0xA1
